#ifndef BH1750_H
#define BH1750_H

#include "Arduino.h"

// ****** USER CONFIGURABLE DATA BEGIN ****** //
// Please check if these values match your setup!

// BH1750 can have 2 possible addresses on the bus, 0x23 ("Low") or 0x5C ("High")
// If white LED blinks 1 second, I2C communication is NOK and you might want to check
// the adddress...
#define BH1750_I2CADDR_LOW 0x23
#define BH1750_I2CADDR_HIGH 0x5c

// ****** USER CONFIGURABLE DATA END ****** //

// Start measurement at 1 lx resolution. Measurement time is approx 120ms.
#define BH1750_CONTINUOUS_HIGH_RES_MODE         0x10

// Start measurement at 0.5 lx resolution. Measurement time is approx 120ms.
#define BH1750_CONTINUOUS_HIGH_RES_MODE_2       0x11

// Start measurement at 4 lx resolution. Measurement time is approx 16ms.
#define BH1750_CONTINUOUS_LOW_RES_MODE          0x13

// Start measurement at 1 lx resolution. Measurement time is approx 120ms.
// Device is automatically set to Power Down after measurement.
#define BH1750_ONE_TIME_HIGH_RES_MODE           0x20

// Start measurement at 0.5 lx resolution. Measurement time is approx 120ms.
// Device is automatically set to Power Down after measurement.
#define BH1750_ONE_TIME_HIGH_RES_MODE_2         0x21

// Start measurement at 1 lx resolution. Measurement time is approx 120ms.
// Device is automatically set to Power Down after measurement.
#define BH1750_ONE_TIME_LOW_RES_MODE            0x23

// Simplified BH1750 interface, based on Z-Uno 2.1.0 BH1750 library.
// I cannot use the library included on the Z-Uno platform, because:
// a) It does not support ligt levels above about 13000 Lux
// b) It does not let you know if I2C was OK or not.

class BH1750 {
  private:
    byte sensorAddress;

  public:
    BH1750();

    // lightLux is luminance measured in Lux.
    // Type long is 32-bit signed, which may seem odd for luminance, but
    // Z-wave uses signed data for reporting, so that is what I use!
    long lightLux;

    /* byte I2Cstatus meaning:
    *
    * 0:success
    * 1:data too long to fit in transmit buffer
    * 2:received NACK on transmit of address
    * 3:received NACK on transmit of data
    * 4:other error
    */
    byte I2Cstatus;

    void begin(uint8_t mode = BH1750_CONTINUOUS_HIGH_RES_MODE, uint8_t addr = BH1750_I2CADDR_LOW);

    void readLightLevel();
};



#endif
